summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qpopupmenu_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qpopupmenu_imp.h')
-rw-r--r--kjsembed/qtbindings/qpopupmenu_imp.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kjsembed/qtbindings/qpopupmenu_imp.h b/kjsembed/qtbindings/qpopupmenu_imp.h
index 3a0c019d..38e1bdfc 100644
--- a/kjsembed/qtbindings/qpopupmenu_imp.h
+++ b/kjsembed/qtbindings/qpopupmenu_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQPopupMenu;
+class TTQPopupMenu;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQPopupMenu;
namespace KJSEmbed {
/**
* Wrapper class for TQPopupMenu methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QPopupMenuImp : public JSProxyImp
+class TQPopupMenuImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -54,8 +54,8 @@ public:
Method_Last = -1
};
- QPopupMenuImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QPopupMenuImp();
+ TQPopupMenuImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQPopupMenuImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -69,13 +69,13 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQPopupMenu *toQPopupMenu( KJS::Object &object );
+ static TTQPopupMenu *toTQPopupMenu( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QPopupMenu_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQPopupMenu_1( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -116,7 +116,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQPopupMenu *instance; // Temp
+ TTQPopupMenu *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQPopupMenu;
namespace KJSEmbed {
/**
- * Wrapper class for TQPopupMenu methods.
+ * Wrapper class for TTQPopupMenu methods.
*
* @author Richard Moore, rich@kde.org